==> robbyson-library-1.0.12.tgz: package/libcontractor/index.js <==
var contractorRepository = require('./contractor-repository.js')
var LINQ = require('node-linq').LINQ;
var config = require('./config.js');

var library = function() {

    this.contratante = null;
    this.contratantesIds = [];


    this.getDataBaseConnection = function(contratante_id, sgdb, application) {
        if (!this.contratante) {
            console.log("No contratante Database Loaded");
            return;
        }

        var connection = new LINQ(this.contratante).Where(function(m) {
            return m.contractor._id == contratante_id && m.databaseType == sgdb && m.application.handle == application;
        }).FirstOrDefault();

        try {
            var response = {
                "Servidor": connection.databaseType == "MONGODB" ? (connection.server + ":" + connection.port) : connection.server,
                "Usuario": connection.user,
                "Senha": connection.password,
                "BancoDeDados": connection.database
            };
        } catch (error) {
            throw error;
        }

        return response;
    };

    this.getContractors = function(callback_success, callback_error) {
        var self = this;
        if (this.contratante)
            if (callback_success) {
                callback_success(this.contratante);
                return;
            }

        function success(data) {
            self.contratante = data;
            self.contratantesIds = getContractorsIds(data);
            if (callback_success)
                callback_success(data);
        }

        function error(err) {
            if (callback_error)
                callback_error(err);
        }

        contractorRepository.getConnections().then(function(response) {
            success(response.records);
        }).catch(function(err) {
            error(err);
        });
    };

    /*
        TODO: Este método sera descontinuado favor não criar
        novas implementações com ele
    */
    this.getContratantes = function(callback_success, callback_error) {
        return this.getContractors(callback_success, callback_error);
    };

    function getContractorsIds(data) {
        var contratantes_ids = new LINQ(data).Select(function(item) {
            return item.contractor._id;
        }).ToArray();

        return arrayDistinct(contratantes_ids);
    };

    function arrayDistinct(arr) {
        var result = [];

        for (i = 0; i < arr.length; i++) {

            if (new LINQ(result).Any(function(item) { return item == arr[i] }) == false) {
                result.push(arr[i]);
            }
        }

        return result;
    };
};

module.exports = new library();

==> robbyson-library-1.0.25.tgz: package/libcontractor/index.js <==
var contractorRepository = require('./contractor-repository.js')
var LINQ = require('node-linq').LINQ;
var config = require('./config.js');

var library = function() {

    this.contratante = null;
    this.contratantesIds = [];


    this.getDataBaseConnection = function(contratante_id, sgdb, application) {
        if (!this.contratante) {
            console.log("No contratante Database Loaded");
            return;
        }

        var connection = new LINQ(this.contratante).Where(function(m) {
            return m.contractor._id == contratante_id && m.databaseType.toLowerCase() == sgdb.toLowerCase() && m.application.handle.toLowerCase() == application.toLowerCase();
        }).FirstOrDefault();

        try {
            var response = {
                "Servidor": connection.databaseType == "MONGODB" ? (connection.server + ":" + connection.port) : connection.server,
                "Usuario": connection.user,
                "Senha": connection.password,
                "BancoDeDados": connection.database
            };
        } catch (error) {
            throw error;
        }

        return response;
    };

    this.getContractors = function(callback_success, callback_error) {
        var self = this;
        if (this.contratante)
            if (callback_success) {
                callback_success(this.contratante);
                return;
            }

        function success(data) {
            self.contratante = data;
            self.contratantesIds = getContractorsIds(data);
            if (callback_success)
                callback_success(data);
        }

        function error(err) {
            if (callback_error)
                callback_error(err);
        }

        contractorRepository.getConnections().then(function(response) {
            success(response.records);
        }).catch(function(err) {
            error(err);
        });
    };

    /*
        TODO: Este método sera descontinuado favor não criar
        novas implementações com ele
    */
    this.getContratantes = function(callback_success, callback_error) {
        return this.getContractors(callback_success, callback_error);
    };

    function getContractorsIds(data) {
        var contratantes_ids = new LINQ(data).Select(function(item) {
            return item.contractor._id;
        }).ToArray();

        return arrayDistinct(contratantes_ids);
    };

    function arrayDistinct(arr) {
        var result = [];

        for (i = 0; i < arr.length; i++) {

            if (new LINQ(result).Any(function(item) { return item == arr[i] }) == false) {
                result.push(arr[i]);
            }
        }

        return result;
    };
};

module.exports = new library();
